@@ -44,13 +44,13 @@ public:
     uint32_t capabilities() const;
     uint32_t rgbRange() const;
 
-    OutputPtr toKScreenOutput();
-    void updateKScreenOutput(OutputPtr &output);
+    OutputPtr toKScreenOutput(const QMap<int, WaylandOutputDevice *> &outputMap);
+    void updateKScreenOutput(OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap);
     void updateKScreenModes(OutputPtr &output);
 
     void setIndex(uint32_t priority);
     uint32_t index() const;
-    bool setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output);
+    bool setWlConfig(WaylandOutputConfiguration *wlConfig, const KScreen::OutputPtr &output, const QMap<int, WaylandOutputDevice *> &outputMap);
 
     QString modeId() const;
     QString uuid() const
@@ -96,6 +96,12 @@ protected:
     void kde_output_device_v2_brightness(uint32_t brightness) override;
     void kde_output_device_v2_color_power_tradeoff(uint32_t preference) override;
     void kde_output_device_v2_dimming(uint32_t dimming) override;
+    void kde_output_device_v2_replication_source(const QString &source) override;
+    void kde_output_device_v2_ddc_ci_allowed(uint32_t allowed) override;
+    void kde_output_device_v2_max_bits_per_color(uint32_t max_bpc) override;
+    void kde_output_device_v2_max_bits_per_color_range(uint32_t min_value, uint32_t max_value) override;
+    void kde_output_device_v2_automatic_max_bits_per_color_limit(uint32_t max_bpc_limit) override;
+    void kde_output_device_v2_edr_policy(uint32_t policy) override;
 
 private:
     QString modeName(const WaylandOutputDeviceMode *m) const;
@@ -136,9 +142,18 @@ private:
     std::optional<double> m_minBrightnessOverride;
     double m_sdrGamutWideness = 0;
     uint32_t m_colorProfileSource = color_profile_source_sRGB;
+    bool m_ddcCiAllowed = true;
     uint32_t m_brightness = 10'000;
     color_power_tradeoff m_colorPowerPreference = color_power_tradeoff_efficiency;
     uint32_t m_dimming = 10'000;
+    QString m_replicationSource;
+    uint32_t m_maxBpc = 0;
+    uint32_t m_autoMaxBpcLimit = 0;
+    struct {
+        uint32_t min = 0;
+        uint32_t max = 0;
+    } bpcRange;
+    uint32_t m_edrPolicy = edr_policy_always;
 };
 
 }
