@@ -80,6 +80,12 @@ public:
         , brightness(other.brightness)
         , colorPowerPreference(other.colorPowerPreference)
         , dimming(other.dimming)
+        , uuid(other.uuid)
+        , ddcCiAllowed(other.ddcCiAllowed)
+        , maxBitsPerColor(other.maxBitsPerColor)
+        , bitsPerColorRange(other.bitsPerColorRange)
+        , automaticMaxBitsPerColorLimit(other.automaticMaxBitsPerColorLimit)
+        , edrPolicy(other.edrPolicy)
     {
         const auto otherModeList = other.modeList;
         for (const ModePtr &otherMode : otherModeList) {
@@ -139,6 +145,12 @@ public:
     double brightness = 1.0;
     ColorPowerTradeoff colorPowerPreference = ColorPowerTradeoff::PreferEfficiency;
     double dimming = 1.0;
+    QString uuid;
+    bool ddcCiAllowed = true;
+    uint32_t maxBitsPerColor = 0;
+    BpcRange bitsPerColorRange;
+    uint32_t automaticMaxBitsPerColorLimit = 0;
+    EdrPolicy edrPolicy = EdrPolicy::Always;
 };
 
 bool Output::Private::compareModeList(const ModeList &before, const ModeList &after)
@@ -948,6 +960,84 @@ void Output::setDimming(double dimming)
     }
 }
 
+QString Output::uuid() const
+{
+    return d->uuid;
+}
+
+void Output::setUuid(const QString &id)
+{
+    if (d->uuid != id) {
+        d->uuid = id;
+        Q_EMIT uuidChanged();
+    }
+}
+
+bool Output::ddcCiAllowed() const
+{
+    return d->ddcCiAllowed;
+}
+
+void Output::setDdcCiAllowed(bool allowed)
+{
+    if (d->ddcCiAllowed != allowed) {
+        d->ddcCiAllowed = allowed;
+        Q_EMIT ddcCiAllowedChanged();
+    }
+}
+
+uint32_t Output::maxBitsPerColor() const
+{
+    return d->maxBitsPerColor;
+}
+
+void Output::setMaxBitsPerColor(uint32_t value)
+{
+    if (d->maxBitsPerColor != value) {
+        d->maxBitsPerColor = value;
+        Q_EMIT maxBitsPerColorChanged();
+    }
+}
+
+Output::BpcRange Output::bitsPerColorRange() const
+{
+    return d->bitsPerColorRange;
+}
+
+void Output::setBitsPerColorRange(BpcRange range)
+{
+    if (d->bitsPerColorRange != range) {
+        d->bitsPerColorRange = range;
+        Q_EMIT maxBitsPerColorChanged();
+    }
+}
+
+uint32_t Output::automaticMaxBitsPerColorLimit() const
+{
+    return d->automaticMaxBitsPerColorLimit;
+}
+
+void Output::setAutomaticMaxBitsPerColorLimit(uint32_t chosenValue)
+{
+    if (d->automaticMaxBitsPerColorLimit != chosenValue) {
+        d->automaticMaxBitsPerColorLimit = chosenValue;
+        Q_EMIT maxBitsPerColorChanged();
+    }
+}
+
+Output::EdrPolicy Output::edrPolicy() const
+{
+    return d->edrPolicy;
+}
+
+void Output::setEdrPolicy(EdrPolicy policy)
+{
+    if (d->edrPolicy != policy) {
+        d->edrPolicy = policy;
+        Q_EMIT edrPolicy();
+    }
+}
+
 void Output::apply(const OutputPtr &other)
 {
     typedef void (KScreen::Output::*ChangeSignal)();
@@ -1098,6 +1188,25 @@ void Output::apply(const OutputPtr &other)
         changes << &Output::dimmingChanged;
         setDimming(other->d->dimming);
     }
+    if (d->uuid != other->d->uuid) {
+        changes << &Output::uuidChanged;
+        setUuid(other->d->uuid);
+    }
+    if (d->ddcCiAllowed != other->d->ddcCiAllowed) {
+        changes << &Output::ddcCiAllowedChanged;
+        setDdcCiAllowed(other->d->ddcCiAllowed);
+    }
+    if (d->maxBitsPerColor != other->d->maxBitsPerColor || d->bitsPerColorRange != other->d->bitsPerColorRange
+        || d->automaticMaxBitsPerColorLimit != other->d->automaticMaxBitsPerColorLimit) {
+        changes << &Output::maxBitsPerColorChanged;
+        setMaxBitsPerColor(other->d->maxBitsPerColor);
+        setBitsPerColorRange(other->d->bitsPerColorRange);
+        setAutomaticMaxBitsPerColorLimit(other->d->automaticMaxBitsPerColorLimit);
+    }
+    if (d->edrPolicy != other->d->edrPolicy) {
+        changes << &Output::edrPolicyChanged;
+        setEdrPolicy(other->d->edrPolicy);
+    }
 
     // Non-notifyable changes
     if (other->d->edid) {
