@@ -64,6 +64,7 @@ public:
     Q_PROPERTY(double brightness READ brightness WRITE setBrightness NOTIFY brightnessChanged)
     Q_PROPERTY(ColorPowerTradeoff colorPowerPreference READ colorPowerPreference WRITE setColorPowerPreference NOTIFY colorPowerPreferenceChanged)
     Q_PROPERTY(double dimming READ dimming WRITE setDimming NOTIFY dimmingChanged)
+    Q_PROPERTY(bool ddcCiAllowed READ ddcCiAllowed WRITE setDdcCiAllowed NOTIFY ddcCiAllowedChanged)
 
     enum Type {
         Unknown,
@@ -105,6 +106,10 @@ public:
         AutoRotation = 1 << 5,
         IccProfile = 1 << 6,
         BrightnessControl = 1 << 7,
+        BuiltInColorProfile = 1 << 8,
+        DdcCi = 1 << 9,
+        MaxBitsPerColor = 1 << 10,
+        ExtendedDynamicRange = 1 << 11,
     };
     Q_ENUM(Capability)
     Q_DECLARE_FLAGS(Capabilities, Capability)
@@ -144,6 +149,12 @@ public:
     };
     Q_ENUM(ColorPowerTradeoff)
 
+    enum class EdrPolicy {
+        Never = 0,
+        Always,
+    };
+    Q_ENUM(EdrPolicy)
+
     explicit Output();
     ~Output() override;
 
@@ -549,6 +560,30 @@ public:
     double dimming() const;
     void setDimming(double dimming);
 
+    QString uuid() const;
+    void setUuid(const QString &id);
+
+    bool ddcCiAllowed() const;
+    void setDdcCiAllowed(bool allowed);
+
+    /**
+     * 0 if no limit is set
+     */
+    uint32_t maxBitsPerColor() const;
+    void setMaxBitsPerColor(uint32_t maxBitsPerColor);
+    struct BpcRange {
+        uint32_t min = 0;
+        uint32_t max = 0;
+        auto operator<=>(const BpcRange &) const = default;
+    };
+    BpcRange bitsPerColorRange() const;
+    void setBitsPerColorRange(BpcRange range);
+    uint32_t automaticMaxBitsPerColorLimit() const;
+    void setAutomaticMaxBitsPerColorLimit(uint32_t chosenValue);
+
+    EdrPolicy edrPolicy() const;
+    void setEdrPolicy(EdrPolicy policy);
+
     void apply(const OutputPtr &other);
 
 Q_SIGNALS:
@@ -587,6 +622,10 @@ Q_SIGNALS:
     void modelChanged();
     void colorPowerPreferenceChanged();
     void dimmingChanged();
+    void uuidChanged();
+    void ddcCiAllowedChanged();
+    void maxBitsPerColorChanged();
+    void edrPolicyChanged();
 
     /** The mode list changed.
      *
